@@ -3,6 +3,8 @@ import asyncio
 from itertools import chain
 from os import PathLike
 from pathlib import Path
+import pprint
+import textwrap
 from typing import ClassVar, Iterable, List, Sequence, Type, Union
 
 from diot import Diot
@@ -11,7 +13,7 @@ from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
 from rich.console import Group
-from simpleconf import Config
+from simpleconf import ProfileConfig
 from slugify import slugify  # type: ignore
 from varname import varname, VarnameException
 
@@ -88,6 +90,11 @@ class Pipen:
         # We shouldn't update the config here, since we don't know
         # the profile yet
         self._kwargs = kwargs
+        # Initialize the workdir, as workdir is created before _init()
+        # But the config is updated in _init()
+        # Here we hack it to have the workdir passed in.
+        if "workdir" in kwargs:
+            self.config.workdir = kwargs["workdir"]
 
         if not self.__class__.SETUP:  # pragma: no cover
             # Load plugins from entrypotins at runtime to avoid
@@ -209,7 +216,7 @@ class Pipen:
     def set_starts(
         self,
         *procs: Union[Type[Proc], Sequence[Type[Proc]]],
-        clear: bool = True
+        clear: bool = True,
     ):
         """Set the starts
 
@@ -276,12 +283,53 @@ class Pipen:
                     self.outdir,
                 ],
             ),
-            sorted(self.config.items()),
+            sorted(
+                (key, val)
+                for key, val in self.config.items()
+                if not key.endswith("_opts")
+            ),
+            (
+                (
+                    "plugin_opts",
+                    pprint.pformat(self.config.plugin_opts, indent=1),
+                ),
+                (
+                    "scheduler_opts",
+                    pprint.pformat(self.config.scheduler_opts, indent=1),
+                ),
+                (
+                    "template_opts",
+                    pprint.pformat(
+                        {
+                            key: (
+                                {
+                                    ckey: textwrap.shorten(
+                                        str(cval),
+                                        width=30 - len(key),
+                                        placeholder=" …",
+                                    )
+                                    for ckey, cval in chain(
+                                        list(val.items())[:3],
+                                        []
+                                        if len(val) <= 3
+                                        else [("...", "...")],
+                                    )
+                                }
+                                if isinstance(val, dict)
+                                else val
+                            )
+                            for key, val in self.config.template_opts.items()
+                        },
+                        indent=1,
+                        # sort_dicts=False,
+                    ),
+                ),
+            ),
         ):
             items_table.add_row(
                 Text.assemble((key, "scope.key")),
                 Text.assemble(("=", "scope.equals")),
-                str(value),
+                Text(str(value), overflow="fold"),
             )
 
         logger.info("")
@@ -317,12 +365,14 @@ class Pipen:
         4. **kwargs from Pipen(..., **kwargs)
         5. Those defined in each Proc class
         """
-
         # Then load the configurations from config files
-        config = Config()
-        config._load(*CONFIG_FILES)
-        config._use(self.profile)
-        self.config.update(config)
+        config = ProfileConfig.load(
+            {"default": self.config},
+            *CONFIG_FILES,
+            ignore_nonexist=True,
+        )
+        self.config = ProfileConfig.use_profile(
+            config, self.profile, copy=True)
 
         # configs from files and CONFIG are loaded
         # allow plugins to change the default configs
@@ -357,8 +407,7 @@ class Pipen:
             logger.debug("- Next processes: %s", nexts)
             # pick up one that can be added to procs
             for proc in sorted(
-                nexts,
-                key=lambda prc: (prc.order or 0, prc.name)
+                nexts, key=lambda prc: (prc.order or 0, prc.name)
             ):
                 if proc in self.procs:
                     raise ProcDependencyError(
