@@ -6,6 +6,7 @@ from os import PathLike
 from collections import defaultdict
 from pathlib import Path
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     DefaultDict,
@@ -13,10 +14,12 @@ from typing import (
     List,
     Mapping,
     Tuple,
+    Type,
     Union,
 )
 
-import pandas
+if TYPE_CHECKING:  # pragma: no cover
+    import pandas
 
 try:  # pragma: no cover
     from functools import cached_property
@@ -111,7 +114,7 @@ def desc_from_docstring(obj: Any) -> str:
     Returns:
         The summary as desc
     """
-    if not obj.__doc__:
+    if not obj.__doc__:  # pragma: no cover
         return None
 
     started: bool = False
@@ -417,7 +420,7 @@ def truncate_text(text: str, width: int, end: str = "…") -> str:
     return text[: (width - len(end))] + end
 
 
-def make_df_colnames_unique_inplace(thedf: pandas.DataFrame) -> None:
+def make_df_colnames_unique_inplace(thedf: "pandas.DataFrame") -> None:
     """Make the columns of a data frame unique
 
     Args:
@@ -432,3 +435,30 @@ def make_df_colnames_unique_inplace(thedf: pandas.DataFrame) -> None:
             new_cols.append(f"{col}_{col_counts[col]}")
         col_counts[col] += 1
     thedf.columns = new_cols
+
+
+def get_base(
+    klass: Type,
+    abc_base: Type,
+    value: Any,
+    value_getter: Callable,
+) -> Type:
+    """Get the base class where the value was first defined
+
+    Args:
+        klass: The class
+        abc_base: The very base class to check in __bases__
+        value: The value to check
+        value_getter: How to get the value from the class
+
+    Returns:
+        The base class
+    """
+    bases = [
+        base for base in klass.__bases__
+        if issubclass(base, abc_base) and value_getter(base) == value
+    ]
+    if not bases:
+        return klass
+
+    return get_base(bases[0], abc_base, value, value_getter)
